summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/reference/telepathy-glib-sections.txt18
-rw-r--r--telepathy-glib/account.c6
-rw-r--r--telepathy-glib/base-call-channel.c28
-rw-r--r--telepathy-glib/base-call-content.c4
-rw-r--r--telepathy-glib/base-client.c2
-rw-r--r--telepathy-glib/base-connection-manager.c12
-rw-r--r--telepathy-glib/base-connection.c3
-rw-r--r--telepathy-glib/base-contact-list.c2
-rw-r--r--telepathy-glib/base-media-call-content.c2
-rw-r--r--telepathy-glib/base-media-call-stream.c4
-rw-r--r--telepathy-glib/base-password-channel.c2
-rw-r--r--telepathy-glib/call-channel.c16
-rw-r--r--telepathy-glib/call-content-media-description.c24
-rw-r--r--telepathy-glib/call-content-media-description.h2
-rw-r--r--telepathy-glib/call-content.c6
-rw-r--r--telepathy-glib/call-stream-endpoint.c6
-rw-r--r--telepathy-glib/call-stream.c6
-rw-r--r--telepathy-glib/cm-message.c2
-rw-r--r--telepathy-glib/dbus-properties-mixin.c2
-rw-r--r--telepathy-glib/dbus-tube-channel.c4
-rw-r--r--telepathy-glib/debug-sender.c2
-rw-r--r--telepathy-glib/errors.c22
-rw-r--r--telepathy-glib/gnio-util.c2
-rw-r--r--telepathy-glib/handle.h2
-rw-r--r--telepathy-glib/message.c2
-rw-r--r--telepathy-glib/presence-mixin.c76
-rw-r--r--telepathy-glib/properties-mixin.c2
-rw-r--r--telepathy-glib/protocol.c6
-rw-r--r--telepathy-glib/simple-client-factory.c9
-rw-r--r--telepathy-glib/stream-tube-channel.c2
-rw-r--r--telepathy-glib/stream-tube-connection.c2
-rw-r--r--telepathy-glib/text-channel.c8
-rw-r--r--tools/c-constants-gen.py3
33 files changed, 116 insertions, 173 deletions
diff --git a/docs/reference/telepathy-glib-sections.txt b/docs/reference/telepathy-glib-sections.txt
index 0df19b1d3..d5023dcfd 100644
--- a/docs/reference/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib-sections.txt
@@ -1474,9 +1474,6 @@ tp_svc_connection_interface_contact_list_return_from_unpublish
tp_svc_connection_interface_contact_list_return_from_unsubscribe
tp_svc_connection_interface_contact_list_unpublish_impl
tp_svc_connection_interface_contact_list_unsubscribe_impl
-tp_svc_connection_interface_contact_list_download_impl
-tp_svc_connection_interface_contact_list_implement_download
-tp_svc_connection_interface_contact_list_return_from_download
<SUBSECTION Standard>
tp_svc_connection_interface_contact_blocking_get_type
tp_svc_connection_interface_contact_list_get_type
@@ -1895,11 +1892,6 @@ TP_ARRAY_TYPE_PROPERTY_FLAGS_CHANGE_LIST
TP_STRUCT_TYPE_PROPERTY_VALUE
TP_ARRAY_TYPE_PROPERTY_VALUE_LIST
<SUBSECTION>
-# Channel - Call
-TP_HASH_TYPE_CALL_MEMBER_MAP
-TP_ARRAY_TYPE_CALL_MEMBER_MAP_LIST
-TP_STRUCT_TYPE_CALL_STATE_REASON
-<SUBSECTION>
# Channel - Media-related
TP_ARRAY_TYPE_MEDIA_SESSION_HANDLER_INFO_LIST
TP_STRUCT_TYPE_MEDIA_SESSION_HANDLER_INFO
@@ -1958,6 +1950,7 @@ TP_ARRAY_TYPE_TLS_CERTIFICATE_REJECTION_LIST
<SUBSECTION>
# Metadata
TP_HASH_TYPE_METADATA
+<SUBSECTION>
# Call
TP_ARRAY_TYPE_CALL_MEMBER_MAP_LIST
TP_ARRAY_TYPE_CANDIDATE_LIST
@@ -2086,7 +2079,6 @@ tp_type_dbus_struct_uuusa_7bsv_7du
tp_type_dbus_struct_uuuuus
tp_type_dbus_struct_uuuuuu
tp_type_dbus_struct_uv
-tp_type_dbus_array_of_a_7buu_7d
tp_type_dbus_array_ussuas
tp_type_dbus_hash_su
tp_type_dbus_struct_ussuas
@@ -3090,8 +3082,6 @@ TP_IFACE_CLIENT_OBSERVER
TP_IFACE_QUARK_CLIENT_OBSERVER
TP_IFACE_CLIENT_INTERFACE_REQUESTS
TP_IFACE_QUARK_CLIENT_INTERFACE_REQUESTS
-TP_IFACE_CHANNEL_TYPE_CALL
-TP_IFACE_QUARK_CHANNEL_TYPE_CALL
TP_IFACE_CALL_CONTENT
TP_IFACE_QUARK_CALL_CONTENT
TP_IFACE_CALL_CONTENT_INTERFACE_MEDIA
@@ -3456,12 +3446,6 @@ TP_TOKEN_CHANNEL_INTERFACE_MEDIA_SIGNALLING_GTALK_P2P
TP_TOKEN_CHANNEL_INTERFACE_MEDIA_SIGNALLING_ICE_UDP
TP_TOKEN_CHANNEL_INTERFACE_MEDIA_SIGNALLING_WLM_8_5
TP_TOKEN_CHANNEL_INTERFACE_MEDIA_SIGNALLING_WLM_2009
-TP_TOKEN_CHANNEL_TYPE_CALL_AUDIO
-TP_TOKEN_CHANNEL_TYPE_CALL_GTALK_P2P
-TP_TOKEN_CHANNEL_TYPE_CALL_ICE
-TP_TOKEN_CHANNEL_TYPE_CALL_SHM
-TP_TOKEN_CHANNEL_TYPE_CALL_VIDEO
-TP_TOKEN_CHANNEL_TYPE_CALL_WLM_2009
<SUBSECTION Private>
tp_iface_quark_account
diff --git a/telepathy-glib/account.c b/telepathy-glib/account.c
index 66d2d4e10..005a29d8b 100644
--- a/telepathy-glib/account.c
+++ b/telepathy-glib/account.c
@@ -1723,7 +1723,7 @@ tp_account_class_init (TpAccountClass *klass)
G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
/**
- * TpAccount:nickname
+ * TpAccount:nickname:
*
* The nickname that should be set for the user on this account.
*
@@ -1826,7 +1826,7 @@ tp_account_class_init (TpAccountClass *klass)
G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
/**
- * TpAccount:normalized-name
+ * TpAccount:normalized-name:
*
* The normalized form of the user's own unique identifier on this
* protocol. For example, on XMPP accounts this is the user's JID; on
@@ -1925,7 +1925,7 @@ tp_account_class_init (TpAccountClass *klass)
G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
/**
- * TpAccount:storage-restrictions
+ * TpAccount:storage-restrictions:
*
* The storage restrictions for this account.
*
diff --git a/telepathy-glib/base-call-channel.c b/telepathy-glib/base-call-channel.c
index 8eeede71f..b4172d48f 100644
--- a/telepathy-glib/base-call-channel.c
+++ b/telepathy-glib/base-call-channel.c
@@ -522,7 +522,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:initial-audio-name
+ * TpBaseCallChannel:initial-audio-name:
*
* Name to use to create the audio #TpBaseCallContent if
* #TpBaseCallChannel:initial-audio is set to %TRUE.
@@ -537,7 +537,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:initial-video-name
+ * TpBaseCallChannel:initial-video-name:
*
* Name to use to create the video #TpBaseCallContent if
* #TpBaseCallChannel:initial-video is set to %TRUE.
@@ -552,7 +552,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:initial-transport
+ * TpBaseCallChannel:initial-transport:
*
* If set to %TRUE on a requested channel, this indicates the transport that
* should be used for this call.
@@ -567,7 +567,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:mutable-contents
+ * TpBaseCallChannel:mutable-contents:
*
* Indicate to clients whether or not they can add/remove contents.
*
@@ -581,7 +581,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:contents
+ * TpBaseCallChannel:contents:
*
* #GPtrArray of object-paths of the #TpBaseCallContent objects.
*
@@ -595,7 +595,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:hardware-streaming
+ * TpBaseCallChannel:hardware-streaming:
*
* Indicate to clients whether or not this Connection Manager has hardware
* streaming.
@@ -610,7 +610,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:call-state
+ * TpBaseCallChannel:call-state:
*
* The state of this call.
*
@@ -623,7 +623,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
g_object_class_install_property (object_class, PROP_CALL_STATE, param_spec);
/**
- * TpBaseCallChannel:call-flags
+ * TpBaseCallChannel:call-flags:
*
* The flags of this call.
*
@@ -637,7 +637,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:call-state-reason
+ * TpBaseCallChannel:call-state-reason:
*
* The reason for last call state change.
*
@@ -651,7 +651,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:call-state-details
+ * TpBaseCallChannel:call-state-details:
*
* Details on the call state.
*
@@ -665,7 +665,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:call-members
+ * TpBaseCallChannel:call-members:
*
* #GHashTable mapping #TpHandle of each call member to their
* #TpCallMemberFlags.
@@ -680,7 +680,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
param_spec);
/**
- * TpBaseCallChannel:member-identifiers
+ * TpBaseCallChannel:member-identifiers:
*
* #GHashTable mapping #TpHandle of each call member to their identifiers.
*
@@ -695,7 +695,7 @@ tp_base_call_channel_class_init (TpBaseCallChannelClass *klass)
/**
- * TpBaseCallChannel:initial-tones
+ * TpBaseCallChannel:initial-tones:
*
* DTMF Tones to be played on the channel created.
*
@@ -1208,7 +1208,7 @@ tp_base_call_channel_get_call_members (TpBaseCallChannel *self)
* @self: a #TpBaseCallChannel
*
* Must be called when the remote contact accepted the call.
- * #TpBaseCallChannel:state must be either %TP_CALL_STATE_INITIALISED or
+ * #TpBaseCallChannel:call-state must be either %TP_CALL_STATE_INITIALISED or
* %TP_CALL_STATE_INITIALISING and will then change to %TP_CALL_STATE_ACCEPTED.
*
* Must be used only for outgoing calls.
diff --git a/telepathy-glib/base-call-content.c b/telepathy-glib/base-call-content.c
index ee16e492c..4bb32ef8a 100644
--- a/telepathy-glib/base-call-content.c
+++ b/telepathy-glib/base-call-content.c
@@ -514,7 +514,7 @@ tp_base_call_content_class_init (TpBaseCallContentClass *klass)
param_spec);
/**
- * TpBaseCallContent:currently-sending-tones
+ * TpBaseCallContent:currently-sending-tones:
*
* If this content is currently sending tones or not
*
@@ -529,7 +529,7 @@ tp_base_call_content_class_init (TpBaseCallContentClass *klass)
param_spec);
/**
- * TpBaseCallContent:deferred-tones
+ * TpBaseCallContent:deferred-tones:
*
* Tones that are waiting for the user action to play.
*
diff --git a/telepathy-glib/base-client.c b/telepathy-glib/base-client.c
index 6f9277b5d..26cd1cb37 100644
--- a/telepathy-glib/base-client.c
+++ b/telepathy-glib/base-client.c
@@ -161,7 +161,7 @@
*/
/**
- * TpBaseClientDelegatedChannelsCb
+ * TpBaseClientDelegatedChannelsCb:
* @client: a #TpBaseClient instance
* @channels: (element-type TelepathyGLib.Channel): a #GPtrArray of #TpChannel
* @user_data: arbitrary user-supplied data passed to
diff --git a/telepathy-glib/base-connection-manager.c b/telepathy-glib/base-connection-manager.c
index f65a94c04..4f60972e1 100644
--- a/telepathy-glib/base-connection-manager.c
+++ b/telepathy-glib/base-connection-manager.c
@@ -853,8 +853,8 @@ parse_parameters (const TpCMParamSpec *paramspec,
}
-/**
- * tp_base_connection_manager_get_parameters
+/*
+ * tp_base_connection_manager_get_parameters:
*
* Implements D-Bus method GetParameters
* on interface org.freedesktop.Telepathy.ConnectionManager
@@ -906,8 +906,8 @@ tp_base_connection_manager_get_parameters (TpSvcConnectionManager *iface,
}
-/**
- * tp_base_connection_manager_list_protocols
+/*
+ * tp_base_connection_manager_list_protocols:
*
* Implements D-Bus method ListProtocols
* on interface org.freedesktop.Telepathy.ConnectionManager
@@ -942,8 +942,8 @@ tp_base_connection_manager_list_protocols (TpSvcConnectionManager *iface,
}
-/**
- * tp_base_connection_manager_request_connection
+/*
+ * tp_base_connection_manager_request_connection:
*
* Implements D-Bus method RequestConnection
* on interface org.freedesktop.Telepathy.ConnectionManager
diff --git a/telepathy-glib/base-connection.c b/telepathy-glib/base-connection.c
index 44cb4b125..7729d85a7 100644
--- a/telepathy-glib/base-connection.c
+++ b/telepathy-glib/base-connection.c
@@ -159,8 +159,7 @@
* tp_base_connection_add_interfaces().
* @create_channel_managers: Create an array of channel managers for this
* Connection. At least one of this or @create_channel_factories must be set
- * by subclasses to a non-%NULL value.
- * Since: 0.7.15
+ * by subclasses to a non-%NULL value. Since: 0.7.15
*
* The class of a #TpBaseConnection. Many members are virtual methods etc.
* to be filled in in the subclass' class_init function.
diff --git a/telepathy-glib/base-contact-list.c b/telepathy-glib/base-contact-list.c
index 38887aedb..4dc2bd587 100644
--- a/telepathy-glib/base-contact-list.c
+++ b/telepathy-glib/base-contact-list.c
@@ -3211,7 +3211,7 @@ tp_base_contact_list_download_async (TpBaseContactList *self,
* tp_base_contact_list_download_async().
*
* This is a virtual method which may be implemented using
- * #TpContactListClass.download_finish. If the @result
+ * #TpBaseContactListClass.download_finish. If the @result
* will be a #GSimpleAsyncResult, the default implementation may be used.
*
* Returns: %TRUE on success or %FALSE on error
diff --git a/telepathy-glib/base-media-call-content.c b/telepathy-glib/base-media-call-content.c
index 47fc6d2f8..95d855048 100644
--- a/telepathy-glib/base-media-call-content.c
+++ b/telepathy-glib/base-media-call-content.c
@@ -438,7 +438,7 @@ tp_base_media_call_content_class_init (TpBaseMediaCallContentClass *klass)
"deferred-tones");
/**
- * TpBaseMediaCallContent::local-media-description-updated
+ * TpBaseMediaCallContent::local-media-description-updated:
* @self: the #TpCallChannel
* @contact: the remote contact
* @properties: the new media description properties asv
diff --git a/telepathy-glib/base-media-call-stream.c b/telepathy-glib/base-media-call-stream.c
index 5df072777..20dd03d84 100644
--- a/telepathy-glib/base-media-call-stream.c
+++ b/telepathy-glib/base-media-call-stream.c
@@ -59,10 +59,10 @@
* @request_receiving: optional (see #TpBaseCallStream:can-request-receiving);
* virtual method called when user requested receiving from the given remote
* contact. This virtual method should be implemented instead of
- * #TpBaseCallStream.request_receiving
+ * #TpBaseCallStreamClass.request_receiving
* @set_sending: mandatory; virtual method called when user requested to
* start/stop sending to remote contacts. This virtual method should be
- * implemented instead of #TpBaseCallStream.set_sending
+ * implemented instead of #TpBaseCallStreamClass.set_sending
*
* The class structure for #TpBaseMediaCallStream
*
diff --git a/telepathy-glib/base-password-channel.c b/telepathy-glib/base-password-channel.c
index 6e3b53288..f6e230850 100644
--- a/telepathy-glib/base-password-channel.c
+++ b/telepathy-glib/base-password-channel.c
@@ -385,7 +385,7 @@ tp_base_password_channel_class_init (TpBasePasswordChannelClass *tp_base_passwor
param_spec);
/**
- * TpBasePasswordChannel::finished
+ * TpBasePasswordChannel::finished:
* @password: the password provided by the user, or %NULL if the
* authentication has been aborted
* @domain: domain of a #GError indicating why the authentication has been
diff --git a/telepathy-glib/call-channel.c b/telepathy-glib/call-channel.c
index f7d6705b8..4404aaad7 100644
--- a/telepathy-glib/call-channel.c
+++ b/telepathy-glib/call-channel.c
@@ -877,7 +877,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
/**
* TpCallChannel:state:
*
- * A #TpChannelCallState specifying the state of the call.
+ * A #TpCallState specifying the state of the call.
*
* Since: 0.17.5
*/
@@ -1046,7 +1046,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
/**
- * TpCallChannel::content-added
+ * TpCallChannel::content-added:
* @self: the #TpCallChannel
* @content: the newly added #TpCallContent
*
@@ -1066,7 +1066,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
1, G_TYPE_OBJECT);
/**
- * TpCallChannel::content-removed
+ * TpCallChannel::content-removed:
* @self: the #TpCallChannel
* @content: the newly removed #TpCallContent
* @reason: a #TpCallStateReason
@@ -1087,7 +1087,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
2, G_TYPE_OBJECT, TP_TYPE_CALL_STATE_REASON);
/**
- * TpCallChannel::state-changed
+ * TpCallChannel::state-changed:
* @self: the #TpCallChannel
* @state: the new #TpCallState
* @flags: the new #TpCallFlags
@@ -1109,7 +1109,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
G_TYPE_HASH_TABLE);
/**
- * TpCallChannel::members-changed
+ * TpCallChannel::members-changed:
* @self: the #TpCallChannel
* @updates: (type GLib.HashTable) (element-type TelepathyGLib.Contact uint):
* #GHashTable mapping #TpContact to its new #TpCallMemberFlags
@@ -1344,7 +1344,7 @@ tp_call_channel_get_members (TpCallChannel *self)
* tp_call_channel_has_dtmf:
* @self: a #TpCallChannel
*
- * Whether or not %self can send DTMF tones using
+ * Whether or not @self can send DTMF tones using
* tp_call_channel_send_tones_async(). To be able to send DTMF tones, at least
* one of @self's #TpCallChannel:contents must implement
* %TP_IFACE_CALL_CONTENT_INTERFACE_DTMF interface.
@@ -1376,7 +1376,7 @@ tp_call_channel_has_dtmf (TpCallChannel *self)
* tp_call_channel_has_hold:
* @self: a #TpCallChannel
*
- * Whether or not %self has the %TP_IFACE_CHANNEL_INTERFACE_HOLD
+ * Whether or not @self has the %TP_IFACE_CHANNEL_INTERFACE_HOLD
* interfaces
*
* Returns: whether or not @self supports Hold
@@ -1790,7 +1790,7 @@ tp_call_channel_send_tones_finish (TpCallChannel *self,
* @user_data: data to pass to @callback
*
* Requests that the connection manager holds or unholds the call. Watch
- * #TpCallChannel::hold-state property to know when the channel goes on
+ * #TpCallChannel:hold-state property to know when the channel goes on
* hold or is unheld. Unholding may fail if the streaming implementation
* can not obtain all the resources needed to restart the call.
*
diff --git a/telepathy-glib/call-content-media-description.h b/telepathy-glib/call-content-media-description.h
index 2ea3e790b..b03df367d 100644
--- a/telepathy-glib/call-content-media-description.h
+++ b/telepathy-glib/call-content-media-description.h
@@ -128,7 +128,7 @@ void tp_call_content_media_description_set_rtcp_extended_reports (
guint packet_receipt_times_max_size,
guint dlrr_max_size,
TpRCPTXRRTTMode rtt_mode,
- TpRTCPXRStatisticsFlags statistic_flags,
+ TpRTCPXRStatisticsFlags statistics_flags,
gboolean enable_metrics);
void tp_call_content_media_description_add_rtp_header_extensions_interface (
diff --git a/telepathy-glib/call-content.c b/telepathy-glib/call-content.c
index 96584d44a..7db411177 100644
--- a/telepathy-glib/call-content.c
+++ b/telepathy-glib/call-content.c
@@ -653,7 +653,7 @@ tp_call_content_class_init (TpCallContentClass *klass)
/**
- * TpCallContent::removed
+ * TpCallContent::removed:
* @self: the #TpCallContent
*
* The ::removed signal is emitted when @self is removed from
@@ -669,7 +669,7 @@ tp_call_content_class_init (TpCallContentClass *klass)
0);
/**
- * TpCallContent::streams-added
+ * TpCallContent::streams-added:
* @self: the #TpCallContent
* @streams: (type GLib.PtrArray) (element-type TelepathyGLib.CallStream):
* a #GPtrArray of newly added #TpCallStream
@@ -690,7 +690,7 @@ tp_call_content_class_init (TpCallContentClass *klass)
1, G_TYPE_PTR_ARRAY);
/**
- * TpCallContent::streams-removed
+ * TpCallContent::streams-removed:
* @self: the #TpCallContent
* @streams: (type GLib.PtrArray) (element-type TelepathyGLib.CallStream):
* a #GPtrArray of newly removed #TpCallStream
diff --git a/telepathy-glib/call-stream-endpoint.c b/telepathy-glib/call-stream-endpoint.c
index 88b49bd32..3795ecd9d 100644
--- a/telepathy-glib/call-stream-endpoint.c
+++ b/telepathy-glib/call-stream-endpoint.c
@@ -433,7 +433,7 @@ tp_call_stream_endpoint_class_init (TpCallStreamEndpointClass *klass)
G_STRUCT_OFFSET (TpCallStreamEndpointClass, dbus_props_class));
/**
- * TpCallStreamEndpoint::candidate-selected
+ * TpCallStreamEndpoint::candidate-selected:
* @self: the #TpCallStreamEndpoint
* @local_candidate: the local candidate
* @remote_candidate: the remote candidate
@@ -451,7 +451,7 @@ tp_call_stream_endpoint_class_init (TpCallStreamEndpointClass *klass)
2, TP_STRUCT_TYPE_CANDIDATE, TP_STRUCT_TYPE_CANDIDATE);
/**
- * TpCallStreamEndpoint::candidate-accepted
+ * TpCallStreamEndpoint::candidate-accepted:
* @self: the #TpCallStreamEndpoint
* @local_candidate: the local candidate
* @remote_candidate: the remote candidate
@@ -469,7 +469,7 @@ tp_call_stream_endpoint_class_init (TpCallStreamEndpointClass *klass)
2, TP_STRUCT_TYPE_CANDIDATE, TP_STRUCT_TYPE_CANDIDATE);
/**
- * TpCallStreamEndpoint::candidate-rejected
+ * TpCallStreamEndpoint::candidate-rejected:
* @self: the #TpCallStreamEndpoint
* @local_candidate: the local candidate
* @remote_candidate: the remote candidate
diff --git a/telepathy-glib/call-stream.c b/telepathy-glib/call-stream.c
index de5dd38c1..976e3d760 100644
--- a/telepathy-glib/call-stream.c
+++ b/telepathy-glib/call-stream.c
@@ -406,7 +406,7 @@ tp_call_stream_class_init (TpCallStreamClass *klass)
param_spec);
/**
- * TpCallStream::local-sending-state-changed
+ * TpCallStream::local-sending-state-changed:
* @self: the #TpCallStream
* @state: the new #TpSendingState
* @reason: the #TpCallStateReason for the change
@@ -425,7 +425,7 @@ tp_call_stream_class_init (TpCallStreamClass *klass)
G_TYPE_HASH_TABLE);
/**
- * TpCallStream::remote-members-changed
+ * TpCallStream::remote-members-changed:
* @self: the #TpCallStream
* @updates: (type GLib.HashTable) (element-type TelepathyGLib.Contact uint):
* #GHashTable mapping #TpContact to its new #TpSendingState
@@ -510,7 +510,7 @@ tp_call_stream_get_feature_quark_core (void)
*
* <!-- -->
*
- * Returns: the value of #TpCallStream:local-seding-state
+ * Returns: the value of #TpCallStream:local-sending-state
* Since: 0.17.5
*/
TpSendingState
diff --git a/telepathy-glib/cm-message.c b/telepathy-glib/cm-message.c
index 828e55525..ad42d8083 100644
--- a/telepathy-glib/cm-message.c
+++ b/telepathy-glib/cm-message.c
@@ -95,7 +95,7 @@ tp_cm_message_init (TpCMMessage *self)
* <!-- nothing more to say -->
*
* Returns: a newly allocated message suitable to be passed to
- * tp_cm_message_mixin_take_received
+ * tp_cm_message_mixin_take_received()
*
* Since: 0.13.9
*/
diff --git a/telepathy-glib/dbus-properties-mixin.c b/telepathy-glib/dbus-properties-mixin.c
index fc4319fb3..fc9523bb1 100644
--- a/telepathy-glib/dbus-properties-mixin.c
+++ b/telepathy-glib/dbus-properties-mixin.c
@@ -1093,7 +1093,7 @@ tp_dbus_properties_mixin_emit_properties_changed (
* tp_dbus_properties_mixin_emit_properties_changed_varargs: (skip)
* @object: an object which uses the D-Bus properties mixin
* @interface_name: the interface on which properties have changed
- * @...: (unqualified) property names whose values have changed, terminated by
+ * @...: property names (unqualified) whose values have changed, terminated by
* %NULL.
*
* A shortcut for calling tp_dbus_properties_mixin_emit_properties_changed().
diff --git a/telepathy-glib/dbus-tube-channel.c b/telepathy-glib/dbus-tube-channel.c
index 28a9524f4..b796e7bc3 100644
--- a/telepathy-glib/dbus-tube-channel.c
+++ b/telepathy-glib/dbus-tube-channel.c
@@ -596,7 +596,7 @@ out:
}
/**
- * tp_dbus_tube_channel_offer_async
+ * tp_dbus_tube_channel_offer_async:
* @self: an outgoing #TpDBusTubeChannel
* @params: (allow-none) (transfer none): parameters of the tube, or %NULL
* @callback: a callback to call when the tube has been offered
@@ -710,7 +710,7 @@ proxy_prepare_accept_cb (GObject *source,
}
/**
- * tp_dbus_tube_channel_accept_async
+ * tp_dbus_tube_channel_accept_async:
* @self: an incoming #TpDBusTubeChannel
* @callback: a callback to call when the tube has been offered
* @user_data: data to pass to @callback
diff --git a/telepathy-glib/debug-sender.c b/telepathy-glib/debug-sender.c
index 716c5c579..45b776e85 100644
--- a/telepathy-glib/debug-sender.c
+++ b/telepathy-glib/debug-sender.c
@@ -262,7 +262,7 @@ tp_debug_sender_class_init (TpDebugSenderClass *klass)
object_class->constructed = tp_debug_sender_constructed;
/**
- * TpDebugSender:enabled
+ * TpDebugSender:enabled:
*
* %TRUE if the NewDebugMessage signal should be emitted when a new debug
* message is generated.
diff --git a/telepathy-glib/errors.c b/telepathy-glib/errors.c
index 252568795..8000d7fd3 100644
--- a/telepathy-glib/errors.c
+++ b/telepathy-glib/errors.c
@@ -182,40 +182,40 @@
* @TP_ERROR_CERT_REVOKED: org.freedesktop.Telepathy.Error.Cert.Revoked:
* Raised if the server provided an SSL/TLS certificate that has been
* revoked.
- * Since: 0.11.12
+ * Since 0.11.12
* @TP_ERROR_CERT_INSECURE: org.freedesktop.Telepathy.Error.Cert.Insecure:
* Raised if the server provided an SSL/TLS certificate that uses an
* insecure cipher algorithm or is cryptographically weak.
- * Since: 0.11.12
+ * Since 0.11.12
* @TP_ERROR_CERT_LIMIT_EXCEEDED: org.freedesktop.Telepathy.Error.Cert.LimitExceeded:
* Raised if the length in bytes of the server certificate, or the depth
* of the server certificate chain, exceed the limits imposed by the
* crypto library.
- * Since: 0.11.12
+ * Since 0.11.12
* @TP_ERROR_NOT_YET: org.freedesktop.Telepathy.Error.NotYet:
* Raised when the requested functionality is not yet available, but is
* likely to become available after some time has passed.
- * Since: 0.11.15
+ * Since 0.11.15
* @TP_ERROR_REJECTED: org.freedesktop.Telepathy.Error.Rejected:
* Raised when an incoming or outgoing call is rejected by the receiving
* contact.
- * Since: 0.13.2
+ * Since 0.13.2
* @TP_ERROR_PICKED_UP_ELSEWHERE: org.freedesktop.Telepathy.Error.PickedUpElsewhere:
* Raised when a call was terminated as a result of the local user
* picking up the call on a different resource.
- * Since: 0.13.3
+ * Since 0.13.3
* @TP_ERROR_CONFUSED: org.freedesktop.Telepathy.Error.Confused:
* Raised if a server rejects protocol messages from a connection manager
* claiming that they do not make sense, two local processes fail to
* understand each other, or an apparently impossible situation is
* reached. This has a similar meaning to %TP_DBUS_ERROR_INCONSISTENT but
* can be passed between processes via D-Bus.
- * Since: 0.13.7
+ * Since 0.13.7
* @TP_ERROR_SERVICE_CONFUSED: org.freedesktop.Telepathy.Error.ServiceConfused:
* Raised when a server or other piece of infrastructure indicates an
* internal error, or when a message that makes no sense is received from
* a server or other piece of infrastructure.
- * Since: 0.13.7
+ * Since 0.13.7
* @TP_ERROR_EMERGENCY_CALLS_NOT_SUPPORTED:
* org.freedesktop.Telepathy.Error.EmergencyCallsNotSupported:
* Raised when a client attempts to dial a number that is recognized as an
@@ -236,17 +236,17 @@
* <code>org.freedesktop.Telepathy.Error.Media.CodecsIncompatible</code>:
* Raised when the local streaming implementation has no codecs in common
* with the remote side.
- * Since: 0.15.6
+ * Since 0.15.6
* @TP_ERROR_MEDIA_UNSUPPORTED_TYPE:
* <code>org.freedesktop.Telepathy.Error.Media.UnsupportedType</code>:
* The media stream type requested is not supported by either the local or
* remote side.
- * Since: 0.15.6
+ * Since 0.15.6
* @TP_ERROR_MEDIA_STREAMING_ERROR:
* <code>org.freedesktop.Telepathy.Error.Media.StreamingError</code>:
* Raised when the call's streaming implementation has some kind of internal
* error.
- * Since: 0.15.6
+ * Since 0.15.6
* @TP_ERROR_CAPTCHA_NOT_SUPPORTED:
* <code>org.freedesktop.Telepathy.Error.Media.CaptchaNotSupported</code>:
* Raised if no UI is available to present captchas, or if one is
diff --git a/telepathy-glib/gnio-util.c b/telepathy-glib/gnio-util.c
index b6278eb4a..625854e92 100644
--- a/telepathy-glib/gnio-util.c
+++ b/telepathy-glib/gnio-util.c
@@ -337,7 +337,7 @@ _tp_unix_connection_send_credentials_with_byte (GUnixConnection *connection,
#endif
/**
- * tp_unix_connection_send_credentials_with_byte
+ * tp_unix_connection_send_credentials_with_byte:
* @connection: a #GUnixConnection
* @byte: the byte to send with the credentials
* @cancellable: (allow-none): a #GCancellable, or %NULL
diff --git a/telepathy-glib/handle.h b/telepathy-glib/handle.h
index 79ad09737..63743e28b 100644
--- a/telepathy-glib/handle.h
+++ b/telepathy-glib/handle.h
@@ -49,7 +49,7 @@ typedef guint TpHandle;
#define TP_TYPE_HANDLE G_TYPE_UINT
/**
- * TP_UNKNOWN_HANDLE_TYPE
+ * TP_UNKNOWN_HANDLE_TYPE:
*
* An invalid handle type (-1 cast to TpHandleType) used to represent an
* unknown handle type.
diff --git a/telepathy-glib/message.c b/telepathy-glib/message.c
index c2576dc41..2dcfd45d9 100644
--- a/telepathy-glib/message.c
+++ b/telepathy-glib/message.c
@@ -127,7 +127,7 @@ tp_message_init (TpMessage *self)
* <!-- nothing more to say -->
*
* Returns: a newly allocated message suitable to be passed to
- * tp_message_mixin_take_received
+ * tp_message_mixin_take_received()
*
* Since: 0.7.21
* Deprecated: since 0.13.9. Use tp_cm_message_new()
diff --git a/telepathy-glib/presence-mixin.c b/telepathy-glib/presence-mixin.c
index 2a5053567..6b33d7625 100644
--- a/telepathy-glib/presence-mixin.c
+++ b/telepathy-glib/presence-mixin.c
@@ -112,7 +112,7 @@
*/
/**
- * TpPresenceStatusOptionalArgumentSpec
+ * TpPresenceStatusOptionalArgumentSpec:
* @name: Name of the argument as passed over D-Bus
* @dtype: D-Bus type signature of the argument
*
@@ -124,7 +124,7 @@
*/
/**
- * TpPresenceStatusSpec
+ * TpPresenceStatusSpec:
* @name: String identifier of the presence status
* @presence_type: A type value, as specified by #TpConnectionPresenceType
* @self: Indicates if this status may be set on yourself
@@ -303,7 +303,7 @@ static GHashTable *construct_simple_presence_hash (
const TpPresenceStatusSpec *supported_statuses,
GHashTable *contact_statuses);
-/**
+/*
* deep_copy_hashtable
*
* Make a deep copy of a GHashTable.
@@ -648,14 +648,11 @@ tp_presence_mixin_emit_one_presence_update (GObject *obj,
}
-/**
- * tp_presence_mixin_add_status: (skip)
+/*
+ * tp_presence_mixin_add_status:
*
* Implements D-Bus method AddStatus
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_add_status (TpSvcConnectionInterfacePresence *iface,
@@ -675,14 +672,11 @@ tp_presence_mixin_add_status (TpSvcConnectionInterfacePresence *iface,
}
-/**
- * tp_presence_mixin_clear_status: (skip)
+/*
+ * tp_presence_mixin_clear_status:
*
* Implements D-Bus method ClearStatus
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_clear_status (TpSvcConnectionInterfacePresence *iface,
@@ -709,14 +703,11 @@ tp_presence_mixin_clear_status (TpSvcConnectionInterfacePresence *iface,
}
-/**
- * tp_presence_mixin_get_presence: (skip)
+/*
+ * tp_presence_mixin_get_presence:
*
* Implements D-Bus method GetPresence
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_get_presence (TpSvcConnectionInterfacePresence *iface,
@@ -832,14 +823,11 @@ check_status_available (GObject *object,
return TRUE;
}
-/**
- * tp_presence_mixin_get_statuses: (skip)
+/*
+ * tp_presence_mixin_get_statuses:
*
* Implements D-Bus method GetStatuses
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_get_statuses (TpSvcConnectionInterfacePresence *iface,
@@ -900,14 +888,11 @@ tp_presence_mixin_get_statuses (TpSvcConnectionInterfacePresence *iface,
}
-/**
- * tp_presence_mixin_set_last_activity_time: (skip)
+/*
+ * tp_presence_mixin_set_last_activity_time:
*
* Implements D-Bus method SetLastActivityTime
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_set_last_activity_time (TpSvcConnectionInterfacePresence *iface,
@@ -923,14 +908,11 @@ tp_presence_mixin_set_last_activity_time (TpSvcConnectionInterfacePresence *ifac
}
-/**
- * tp_presence_mixin_remove_status: (skip)
+/*
+ * tp_presence_mixin_remove_status:
*
* Implements D-Bus method RemoveStatus
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_remove_status (TpSvcConnectionInterfacePresence *iface,
@@ -999,14 +981,11 @@ tp_presence_mixin_remove_status (TpSvcConnectionInterfacePresence *iface,
}
-/**
- * tp_presence_mixin_request_presence: (skip)
+/*
+ * tp_presence_mixin_request_presence:
*
* Implements D-Bus method RequestPresence
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_request_presence (TpSvcConnectionInterfacePresence *iface,
@@ -1163,14 +1142,11 @@ set_status (
}
-/**
- * tp_presence_mixin_set_status: (skip)
+/*
+ * tp_presence_mixin_set_status:
*
* Implements D-Bus method SetStatus
* on interface org.freedesktop.Telepathy.Connection.Interface.Presence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_set_status (TpSvcConnectionInterfacePresence *iface,
@@ -1368,14 +1344,11 @@ tp_presence_mixin_simple_presence_init_dbus_properties (GObjectClass *cls)
NULL, known_simple_presence_props);
}
-/**
- * tp_presence_mixin_simple_presence_set_presence: (skip)
+/*
+ * tp_presence_mixin_simple_presence_set_presence:
*
* Implements D-Bus method SetPresence
* on interface org.freedesktop.Telepathy.Connection.Interface.SimplePresence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_simple_presence_set_presence (
@@ -1499,14 +1472,11 @@ construct_simple_presence_hash (const TpPresenceStatusSpec *supported_statuses,
return presence_hash;
}
-/**
- * tp_presence_mixin_get_simple_presence: (skip)
+/*
+ * tp_presence_mixin_get_simple_presence:
*
* Implements D-Bus method GetPresence
* on interface org.freedesktop.Telepathy.Connection.Interface.SimplePresence
- *
- * @context: The D-Bus invocation context to use to return values
- * or throw an error.
*/
static void
tp_presence_mixin_simple_presence_get_presences (
diff --git a/telepathy-glib/properties-mixin.c b/telepathy-glib/properties-mixin.c
index d07e2a2a6..38f29a6e3 100644
--- a/telepathy-glib/properties-mixin.c
+++ b/telepathy-glib/properties-mixin.c
@@ -615,7 +615,7 @@ tp_properties_context_remove (TpPropertiesContext *ctx, guint property)
/**
- * tp_properties_context_return
+ * tp_properties_context_return:
* @ctx: the properties context representing a SetProperties call
* @error: If %NULL, return successfully; otherwise return this error
*
diff --git a/telepathy-glib/protocol.c b/telepathy-glib/protocol.c
index 93c704443..34317a107 100644
--- a/telepathy-glib/protocol.c
+++ b/telepathy-glib/protocol.c
@@ -603,7 +603,7 @@ tp_protocol_class_init (TpProtocolClass *klass)
G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
/**
- * TpProtocol:protocol-properties
+ * TpProtocol:protocol-properties:
*
* The immutable properties of this Protocol, as provided at construction
* time. This is a map from string to #GValue, which must not be modified.
@@ -1067,7 +1067,7 @@ tp_protocol_get_icon_name (TpProtocol *self)
}
/**
- * tp_protocol_get_authentication_types
+ * tp_protocol_get_authentication_types:
* @self: a protocol object
*
*
@@ -1680,7 +1680,7 @@ _tp_protocol_parse_manager_file (GKeyFile *file,
}
/**
- * tp_protocol_get_avatar_requirements
+ * tp_protocol_get_avatar_requirements:
* @self: a #TpProtocol
*
* Return the #TpProtocol:avatar-requirements property
diff --git a/telepathy-glib/simple-client-factory.c b/telepathy-glib/simple-client-factory.c
index 0f3993d95..57fb9aff3 100644
--- a/telepathy-glib/simple-client-factory.c
+++ b/telepathy-glib/simple-client-factory.c
@@ -79,15 +79,6 @@
/**
* TpSimpleClientFactoryClass:
- * @parent_class: the parent class
- *
- * The class of a #TpSimpleClientFactory.
- *
- * Since: 0.15.5
- */
-
-/**
- * TpSimpleClientFactoryClass:
* @parent_class: the parent
* @create_account: create a #TpAccount;
* see tp_simple_client_factory_ensure_account()
diff --git a/telepathy-glib/stream-tube-channel.c b/telepathy-glib/stream-tube-channel.c
index 26c6afc47..4f266cf79 100644
--- a/telepathy-glib/stream-tube-channel.c
+++ b/telepathy-glib/stream-tube-channel.c
@@ -439,7 +439,7 @@ tp_stream_tube_channel_class_init (TpStreamTubeChannelClass *klass)
g_object_class_install_property (gobject_class, PROP_PARAMETERS, param_spec);
/**
- * TpStreamTubeChannel::incoming
+ * TpStreamTubeChannel::incoming:
* @self: the #TpStreamTubeChannel
* @tube_connection: the #TpStreamTubeConnection for the connection
*
diff --git a/telepathy-glib/stream-tube-connection.c b/telepathy-glib/stream-tube-connection.c
index a179042af..b48470dc0 100644
--- a/telepathy-glib/stream-tube-connection.c
+++ b/telepathy-glib/stream-tube-connection.c
@@ -239,7 +239,7 @@ tp_stream_tube_connection_class_init (TpStreamTubeConnectionClass *cls)
g_object_class_install_property (object_class, PROP_CONTACT, param_spec);
/**
- * TpStreamTubeConnection::closed
+ * TpStreamTubeConnection::closed:
* @self: the #TpStreamTubeConnection
* @error: (transfer none): a #GError representing the error reported by the
* connection manager
diff --git a/telepathy-glib/text-channel.c b/telepathy-glib/text-channel.c
index 2b2fce6e6..ccbe1525b 100644
--- a/telepathy-glib/text-channel.c
+++ b/telepathy-glib/text-channel.c
@@ -946,7 +946,7 @@ tp_text_channel_class_init (TpTextChannelClass *klass)
g_object_class_install_property (gobject_class, PROP_SMS_FLASH, param_spec);
/**
- * TpTextChannel::message-received
+ * TpTextChannel::message-received:
* @self: the #TpTextChannel
* @message: a #TpSignalledMessage
*
@@ -974,7 +974,7 @@ tp_text_channel_class_init (TpTextChannelClass *klass)
1, TP_TYPE_SIGNALLED_MESSAGE);
/**
- * TpTextChannel::pending-message-removed
+ * TpTextChannel::pending-message-removed:
* @self: the #TpTextChannel
* @message: a #TpSignalledMessage
*
@@ -999,7 +999,7 @@ tp_text_channel_class_init (TpTextChannelClass *klass)
1, TP_TYPE_SIGNALLED_MESSAGE);
/**
- * TpTextChannel::message-sent
+ * TpTextChannel::message-sent:
* @self: the #TpTextChannel
* @message: a #TpSignalledMessage
* @flags: the #TpMessageSendingFlags affecting how the message was sent
@@ -1582,7 +1582,7 @@ tp_text_channel_get_message_types (TpTextChannel *self)
}
/**
- * tp_text_channel_supports_message_type
+ * tp_text_channel_supports_message_type:
* @self: a #TpTextChannel
* @message_type: a #TpChannelTextMessageType
*
diff --git a/tools/c-constants-gen.py b/tools/c-constants-gen.py
index bc0484973..c74d4fdc9 100644
--- a/tools/c-constants-gen.py
+++ b/tools/c-constants-gen.py
@@ -67,8 +67,7 @@ extern "C" {
flags.getAttribute('name')
self.d("""\
/**
- *
-%s:
+ * %s:
""" % (self.prefix + name).replace('_', ''))
for flag in get_by_path(flags, 'flag'):
self.do_gtkdoc(flag, value_prefix)
diff --git a/telepathy-glib/call-content-media-description.c b/telepathy-glib/call-content-media-description.c
index 153d5787b..ff3725cf2 100644
--- a/telepathy-glib/call-content-media-description.c
+++ b/telepathy-glib/call-content-media-description.c
@@ -107,7 +107,7 @@ enum
PROP_PACKET_RECEIPT_TIMES_MAX_SIZE,
PROP_DLRR_MAX_SIZE,
PROP_RTT_MODE,
- PROP_STATISTIC_FLAGS,
+ PROP_STATISTICS_FLAGS,
PROP_ENABLE_METRICS,
};
@@ -136,7 +136,7 @@ struct _TpCallContentMediaDescriptionPrivate
guint packet_receipt_times_max_size;
guint dlrr_max_size;
TpRCPTXRRTTMode rtt_mode;
- TpRTCPXRStatisticsFlags statistic_flags;
+ TpRTCPXRStatisticsFlags statistics_flags;
gboolean enable_metrics;
GSimpleAsyncResult *result;
@@ -255,8 +255,8 @@ tp_call_content_media_description_get_property (GObject *object,
case PROP_RTT_MODE:
g_value_set_uint (value, self->priv->rtt_mode);
break;
- case PROP_STATISTIC_FLAGS:
- g_value_set_uint (value, self->priv->statistic_flags);
+ case PROP_STATISTICS_FLAGS:
+ g_value_set_uint (value, self->priv->statistics_flags);
break;
case PROP_ENABLE_METRICS:
g_value_set_boolean (value, self->priv->enable_metrics);
@@ -623,7 +623,7 @@ tp_call_content_media_description_class_init (
"that are sent, and whether to send VoIP Metrics Report Blocks.",
0, G_MAXUINT, 0,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
- g_object_class_install_property (object_class, PROP_STATISTIC_FLAGS, spec);
+ g_object_class_install_property (object_class, PROP_STATISTICS_FLAGS, spec);
/**
* TpCallContentMediaDescription:enable-metrics:
@@ -662,7 +662,7 @@ tp_call_content_media_description_class_init (
* tp_call_content_media_description_add_ssrc().
*
* Once all information has been filled, the media description can be offered
- * using tp_base_media_call_content_offer_media_description().
+ * using tp_base_media_call_content_offer_media_description_async().
*
* Returns: a new #TpCallContentMediaDescription.
* Since: 0.17.5
@@ -880,7 +880,7 @@ tp_call_content_media_description_add_rtcp_extended_reports_interface (
* @parameters: Feedback parameters as a string. Format is defined in the
* relevant RFC.
*
- * Add an element to the #TpCallContentMediaDescription:rtp-header-extensions
+ * Add an element to the #TpCallContentMediaDescription:header-extensions
* property.
*
* Implement
@@ -1064,9 +1064,9 @@ tp_call_content_media_description_set_does_avpf (
* @dlrr_max_size: the value for
* #TpCallContentMediaDescription:dlrr-max-size property.
* @rtt_mode: the value for
* #TpCallContentMediaDescription:rtt-mpde property.
* @statistic_flags: the value for
* #TpCallContentMediaDescription:statistic-flags property.
* @enable_metrics: the value for
* #TpCallContentMediaDescription:enable-metrics property.
*
@@ -1084,7 +1084,7 @@ tp_call_content_media_description_set_rtcp_extended_reports (
guint packet_receipt_times_max_size,
guint dlrr_max_size,
TpRCPTXRRTTMode rtt_mode,
- TpRTCPXRStatisticsFlags statistic_flags,
+ TpRTCPXRStatisticsFlags statistics_flags,
gboolean enable_metrics)
{
g_return_if_fail (TP_IS_CALL_CONTENT_MEDIA_DESCRIPTION (self));
@@ -1094,7 +1094,7 @@ tp_call_content_media_description_set_rtcp_extended_reports (
self->priv->packet_receipt_times_max_size = packet_receipt_times_max_size;
self->priv->dlrr_max_size = dlrr_max_size;
self->priv->rtt_mode = rtt_mode;
- self->priv->statistic_flags = statistic_flags;
+ self->priv->statistics_flags = statistics_flags;
self->priv->enable_metrics = enable_metrics;
tp_call_content_media_description_add_rtcp_extended_reports_interface (self);
@@ -1064,9 +1064,9 @@ tp_call_content_media_description_set_does_avpf (
* #TpCallContentMediaDescription:dlrr-max-size property.
* @rtt_mode: the value for
- * #TpCallContentMediaDescription:rtt-mpde property.
- * @statistic_flags: the value for
- * #TpCallContentMediaDescription:statistic-flags property.
+ * #TpCallContentMediaDescription:rtt-mode property.
+ * @statistics_flags: the value for
+ * #TpCallContentMediaDescription:statistics-flags property.
* @enable_metrics: the value for
* #TpCallContentMediaDescription:enable-metrics property.